#!/usr/bin/env bash
(%[^ ]+%)/segway-task run train '' chr1 0 8000 1 0 ../simplesubseg.genomedata,../simplesubseg.genomedata asinh_norm 0,1 True '[((%\d+%), (%\d+%))]' '[(%\d%)]' False None None 2 -base 3 -componentCache F -cppCommandOptions (%'(?=.*-\bDCARD_SEG=2\b)(?=.*-\bDINPUT_PARAMS_FILENAME=traindir/params/params\.0\.params\.1\b)(?=.*-\bDCARD_FRAMEINDEX=2000000\b)(?=.*-\bDCARD_SUBSEG=2\b)(?=.*-\bDSEGTRANSITION_WEIGHT_SCALE=1\.0\b).*'%) -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 2 -nf2 0 -ni1 0 -ni2 4 -objsNotToTrain traindir/auxiliary/dont_train.list -obsNAN T -of1 traindir/observations/float32.list -of2 traindir/observations/int.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.2.2.trifile -trrng 0 -verbosity 0
