#!/usr/bin/env bash
(%[^ ]+%)/segway-task run viterbi identifydir-full/viterbi/viterbi0.bed chr1 0 8000 1 0 2 2 full ../simplesubseg.genomedata,../simplesubseg.genomedata asinh_norm 0,1 False None None 1 -base 3 -cVitRegexFilter '^(seg|subseg)$' -cliqueTableNormalize 0.0 -componentCache F -cppCommandOptions (%'(?=.*-\bDCARD_SEG=2\b)()(?=.*-\bDCARD_FRAMEINDEX=2000000\b)(?=.*-\bDCARD_SUBSEG=2\b)(?=.*-\bDSEGTRANSITION_WEIGHT_SCALE=1\.0\b)(?=.*-\bDCARD_SUPERVISIONLABEL=-1\b)(?=.*-\bDINPUT_PARAMS_FILENAME=traindir/params/params\.params\b).*'%) -deterministicChildrenStore F -eVitRegexFilter '^(seg|subseg)$' -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile identifydir-full/log/jt_info.txt -lst 100000 -mVitValsFile - -nf1 2 -nf2 0 -ni1 0 -ni2 2 -obsNAN T -of1 identifydir-full/observations/float32.list -of2 identifydir-full/observations/int.list -pVitRegexFilter '^(seg|subseg)$' -strFile traindir/segway.str -triFile identifydir-full/triangulation/segway.str.2.2.trifile -verbosity 0 -vitCaseSensitiveRegexFilter T
